# 更新日志

## 未发布


## v0.3.3 (2019-03-01)

* 删除内置有道智云账号

## v0.3.2 (2018-08-15)

* 修复发音配置问题 #6

## v0.3.1 (2018-07-17)

* Python 版本要求 >= 3.6

## v0.3 (2018-04-06)

* 缓存翻译结果（缓存在内存中，定时持久化到文件系统）
* 支持发音
    * 使用有道发音(https://dict.youdao.com/dictvoice?le=en&audio=gnome)。需要下载发音文件，会缓存
    * 弹窗显示时自动发音。为保证响应速度，弹窗不会等待发音下载完成，因此自动发音的时间，甚至弹窗消失前能否自动发音是不确定的
    * 点击音标发音
    * 可禁用自动发音，也可完全禁用发音功能（完全禁用后不会下载发音文件）
* 完善选中内容过滤（去除两端空白字符、允许单引号）
* 完善翻译结果处理逻辑

## v0.2 (2018-01-04)

* 限制查询内容长度（2~80个字符）
* 使用 `GLib.timeout_add` 实现自动隐藏弹窗，不再使用单独的线程
* 实现调试模式
* 实现 logging
* 简化多个查询客户端的维护方式（避免显式使用查询客户端独有的配置类、实现类）
* 增加 `--client` 命令行参数，用以指定查询客户端

## v0.1.2 (2017-12-16)

* 删除选中文本中的 [soft hyphen](https://en.wikipedia.org/wiki/Soft_hyphen)

## v0.1.1 (2017-12-15)

* 有道智云查询时指定源语言为英文，使用 auto 会导致偶尔识别错误
* 连字符（"-"）在行尾时，删除换行符。其它情况换行符会替换成空格

## v0.1 (2017-12-13)

实现基本功能，支持有道智云翻译 API
